==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_ssm/waiter.py <==
"""
Type annotations for ssm service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_ssm.client import SSMClient
    from types_boto3_ssm.waiter import (
        CommandExecutedWaiter,
    )

    session = Session()
    client: SSMClient = session.client("ssm")

    command_executed_waiter: CommandExecutedWaiter = client.get_waiter("command_executed")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import GetCommandInvocationRequestCommandExecutedWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("CommandExecutedWaiter",)


class CommandExecutedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm/waiter/CommandExecuted.html#SSM.Waiter.CommandExecuted)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/#commandexecutedwaiter)
    """

    def wait(self, **kwargs: Unpack[GetCommandInvocationRequestCommandExecutedWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm/waiter/CommandExecuted.html#SSM.Waiter.CommandExecuted.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/#commandexecutedwaiter)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_ssm/waiter.py <==
"""
Type annotations for ssm service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_ssm.client import SSMClient
    from types_boto3_ssm.waiter import (
        CommandExecutedWaiter,
    )

    session = Session()
    client: SSMClient = session.client("ssm")

    command_executed_waiter: CommandExecutedWaiter = client.get_waiter("command_executed")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import GetCommandInvocationRequestWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("CommandExecutedWaiter",)


class CommandExecutedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm/waiter/CommandExecuted.html#SSM.Waiter.CommandExecuted)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/#commandexecutedwaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[GetCommandInvocationRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm/waiter/CommandExecuted.html#SSM.Waiter.CommandExecuted.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_ssm/waiters/#commandexecutedwaiter)
        """
